<?php
/**
 * The template for adding Featured Content Settings in Customizer
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */

$wp_customize->add_panel( 'parallax_frame_featured_content', array(
	'capability'  => 'edit_theme_options',
	'description' => esc_html__( 'Featured Content Options', 'parallax-frame-pro' ),
	'priority'    => 800,
	'title'       => esc_html__( 'Featured Content', 'parallax-frame-pro' ),
) );

$wp_customize->add_section( 'parallax_frame_featured_content', array(
	'panel'			=> 'parallax_frame_featured_content',
	'priority'		=> 1,
	'title'			=> esc_html__( 'Featured Content Options', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_option'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$parallax_frame_featured_slider_content_options = parallax_frame_featured_slider_content_options();
$choices = array();
foreach ( $parallax_frame_featured_slider_content_options as $parallax_frame_featured_slider_content_option ) {
	$choices[$parallax_frame_featured_slider_content_option['value']] = $parallax_frame_featured_slider_content_option['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_option]', array(
	'choices'  => $choices,
	'label'    => esc_html__( 'Enable Featured Content on', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_featured_content',
	'settings' => 'parallax_frame_theme_options[featured_content_option]',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_layout]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_layout'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$parallax_frame_featured_content_layout_options = parallax_frame_featured_content_layout_options();
$choices = array();
foreach ( $parallax_frame_featured_content_layout_options as $parallax_frame_featured_content_layout_option ) {
	$choices[$parallax_frame_featured_content_layout_option['value']] = $parallax_frame_featured_content_layout_option['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_layout]', array(
	'active_callback' => 'parallax_frame_is_featured_content_active',
	'choices'         => $choices,
	'label'           => esc_html__( 'Select Featured Content Layout', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_content',
	'settings'        => 'parallax_frame_theme_options[featured_content_layout]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_position]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_position'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_position]', array(
	'active_callback' => 'parallax_frame_is_featured_content_active',
	'label'           => esc_html__( 'Check to Move above Footer', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_content',
	'settings'        => 'parallax_frame_theme_options[featured_content_position]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_slider]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_slider'],
	'sanitize_callback' => 'parallax_frame_sanitize_checkbox'
) );

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_slider]', array(
	'active_callback' => 'parallax_frame_is_featured_content_active',
	'label'           => esc_html__( 'Check to Enable Slider', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_content',
	'settings'        => 'parallax_frame_theme_options[featured_content_slider]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_type]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_type'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$parallax_frame_featured_content_types = parallax_frame_featured_content_types();
$choices = array();
foreach ( $parallax_frame_featured_content_types as $parallax_frame_featured_content_type ) {
	$choices[$parallax_frame_featured_content_type['value']] = $parallax_frame_featured_content_type['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_type]', array(
	'active_callback' => 'parallax_frame_is_featured_content_active',
	'choices'         => $choices,
	'label'           => esc_html__( 'Select Content Type', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_content',
	'settings'        => 'parallax_frame_theme_options[featured_content_type]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_headline]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_headline'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_headline]' , array(
	'active_callback' => 'parallax_frame_is_demo_featured_content_inactive',
	'description'     => esc_html__( 'Leave field empty if you want to remove Headline', 'parallax-frame-pro' ),
	'label'           => esc_html__( 'Headline for Featured Content', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_content',
	'settings'        => 'parallax_frame_theme_options[featured_content_headline]',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_subheadline]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_subheadline'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_subheadline]' , array(
	'active_callback' => 'parallax_frame_is_demo_featured_content_inactive',
	'description'     => esc_html__( 'Leave field empty if you want to remove Sub-headline', 'parallax-frame-pro' ),
	'label'           => esc_html__( 'Sub-headline for Featured Content', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_content',
	'settings'        => 'parallax_frame_theme_options[featured_content_subheadline]',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_number]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_number'],
	'sanitize_callback' => 'parallax_frame_sanitize_number_range',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_number]' , array(
		'active_callback' => 'parallax_frame_is_demo_featured_content_inactive',
		'description'     => esc_html__( 'Save and refresh the page if No. of Featured Content is changed (Max no of Featured Content is 20)', 'parallax-frame-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 45px;',
			'min'   => 0,
			'max'   => 20,
			'step'  => 1,
		),
		'label'           => esc_html__( 'No of Featured Content', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_featured_content',
		'settings'        => 'parallax_frame_theme_options[featured_content_number]',
		'type'            => 'number',
		)
);

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_enable_title]', array(
		'default'           => $defaults['featured_content_enable_title'],
		'sanitize_callback' => 'parallax_frame_sanitize_checkbox',
	) );

$wp_customize->add_control(  'parallax_frame_theme_options[featured_content_enable_title]', array(
	'active_callback' => 'parallax_frame_is_demo_featured_content_inactive',
	'label'           => esc_html__( 'Check to Enable Title', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_content',
	'settings'        => 'parallax_frame_theme_options[featured_content_enable_title]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_show]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_show'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$parallax_frame_featured_content_show = parallax_frame_featured_content_show();
$choices = array();
foreach ( $parallax_frame_featured_content_show as $parallax_frame_featured_content_shows ) {
	$choices[$parallax_frame_featured_content_shows['value']] = $parallax_frame_featured_content_shows['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_show]', array(
	'active_callback' => 'parallax_frame_is_demo_featured_content_inactive',
	'choices'         => $choices,
	'label'           => esc_html__( 'Display Content', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_featured_content',
	'settings'        => 'parallax_frame_theme_options[featured_content_show]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_select_category]', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'parallax_frame_sanitize_category_list',
) );

$wp_customize->add_control( new parallax_frame_customize_dropdown_categories_control( $wp_customize, 'parallax_frame_featured_content_select_category', array(
	'active_callback'	=> 'parallax_frame_is_featured_category_content_active',
    'label'   	=> esc_html__( 'Select Categories', 'parallax-frame-pro' ),
    'name' 		=> 'parallax_frame_theme_options[featured_content_select_category]',
    'section'  	=> 'parallax_frame_featured_content',
    'settings' 	=> 'parallax_frame_theme_options[featured_content_select_category]',
    'type'     	=> 'dropdown-categories',
) ) );


$priority	=	7;

for ( $i=1; $i <=  $options['featured_content_number'] ; $i++ ) {

	//for featured post content
	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_post_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'parallax_frame_sanitize_page',
		)
	);

	$wp_customize->add_control( 'parallax_frame_featured_content_post_'. $i, array(
		'active_callback'	=> 'parallax_frame_is_featured_post_content_active',
		'input_attrs' => array(
        	'style' => 'width: 40px;'
    	),
		'label'    	=> esc_html__( 'Featured Post', 'parallax-frame-pro' ) . ' ' . $i ,
		'section'  	=> 'parallax_frame_featured_content',
		'settings' 	=> 'parallax_frame_theme_options[featured_content_post_'. $i .']',
		'type'	   	=> 'text',
		)
	);

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_page_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_page',
	) );

	$wp_customize->add_control( 'parallax_frame_featured_content_page_'. $i, array(
		'active_callback'	=> 'parallax_frame_is_featured_page_content_active',
		'label'    	=> esc_html__( 'Featured Page', 'parallax-frame-pro' ) . ' ' . $i ,
		'section'  	=> 'parallax_frame_featured_content',
		'settings' 	=> 'parallax_frame_theme_options[featured_content_page_'. $i .']',
		'type'	   	=> 'dropdown-pages',
	) );

	if ( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
		$priority++;

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_note_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new parallax_frame_note_control( $wp_customize, 'featured_content_note_'. $i, array(
		'active_callback'	=> 'parallax_frame_is_featured_image_content_active',
        'label'		=> esc_html__( 'Featured Content #', 'parallax-frame-pro' ) .  $i,
		'section'  	=> 'parallax_frame_featured_content',
        'settings'	=> 'parallax_frame_theme_options[featured_content_note_'. $i .']',
        'type'     	=> 'description',
		) ) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_image_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_content_image_'. $i , array(
		'active_callback'	=> 'parallax_frame_is_featured_image_content_active',
		'label'		=> esc_html__( 'Image', 'parallax-frame-pro' ),
        'section'   => 'parallax_frame_featured_content',
        'settings'  => 'parallax_frame_theme_options[featured_content_image_'. $i .']',
	) ) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_link_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'parallax_frame_theme_options[featured_content_link_'. $i .']', array(
		'active_callback'	=> 'parallax_frame_is_featured_image_content_active',
		'label'		=> esc_html__( 'Link', 'parallax-frame-pro' ),
        'section'   => 'parallax_frame_featured_content',
        'settings'  => 'parallax_frame_theme_options[featured_content_link_'. $i .']',
	) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_target_'. $i .']', array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'parallax_frame_theme_options[featured_content_target_'. $i .']', array(
		'active_callback'	=> 'parallax_frame_is_featured_image_content_active',
		'label'		=> esc_html__( 'Check to Open Link in New Window/Tab', 'parallax-frame-pro' ),
        'section'   => 'parallax_frame_featured_content',
        'settings'  => 'parallax_frame_theme_options[featured_content_target_'. $i .']',
		'type'		=> 'checkbox',
    ) );

    $wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_title_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'parallax_frame_theme_options[featured_content_title_'. $i .']', array(
		'active_callback'	=> 'parallax_frame_is_featured_image_content_active',
		'label'		=> esc_html__( 'Title', 'parallax-frame-pro' ),
        'section'   => 'parallax_frame_featured_content',
        'settings'  => 'parallax_frame_theme_options[featured_content_title_'. $i .']',
		'type'		=> 'text',
    ) );

    $wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_content_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_content_'. $i .']', array(
		'active_callback'	=> 'parallax_frame_is_featured_image_content_active',
		'label'		=> esc_html__( 'Content', 'parallax-frame-pro' ),
        'section'   => 'parallax_frame_featured_content',
        'settings'  => 'parallax_frame_theme_options[featured_content_content_'. $i .']',
		'type'		=> 'textarea',
    ) );
}

$wp_customize->add_section( 'parallax_frame_featured_content_background_settings', array(
	'description'	=> esc_html__( 'Make sure Featured Content is enabled for these options to work', 'parallax-frame-pro' ),
	'panel'			=> 'parallax_frame_featured_content',
	'title'			=> esc_html__( 'Featured Content Background Settings', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_background_image]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_content_background_image'],
		'sanitize_callback'	=> 'esc_url_raw',
	) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'parallax_frame_theme_options[featured_content_background_image]', array(
	'label'		=> esc_html__( 'Select/Add Background Image', 'parallax-frame-pro' ),
	'default'   => $defaults['featured_content_background_image'],
	'section'   => 'parallax_frame_featured_content_background_settings',
    'settings'  => 'parallax_frame_theme_options[featured_content_background_image]',
) ) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_background_display_position]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_background_display_position'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$parallax_frame_featured_content_background_display_positions = parallax_frame_featured_content_background_display_positions();
$choices = array();
foreach ( $parallax_frame_featured_content_background_display_positions as $parallax_frame_featured_content_background_display_position ) {
	$choices[$parallax_frame_featured_content_background_display_position['value']] = $parallax_frame_featured_content_background_display_position['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_background_display_position]', array(
	'choices'  	=> $choices,
	'label'    	=> esc_html__( 'Display Position', 'parallax-frame-pro' ),
	'section'  	=> 'parallax_frame_featured_content_background_settings',
	'settings' 	=> 'parallax_frame_theme_options[featured_content_background_display_position]',
	'type'	  	=> 'radio',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_background_repeat]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_background_repeat'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$parallax_frame_featured_content_background_repeat_options = parallax_frame_featured_content_background_repeat_options();
$choices = array();
foreach ( $parallax_frame_featured_content_background_repeat_options as $parallax_frame_featured_content_background_repeat_option ) {
	$choices[$parallax_frame_featured_content_background_repeat_option['value']] = $parallax_frame_featured_content_background_repeat_option['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_background_repeat]', array(
	'choices'  	=> $choices,
	'label'    	=> esc_html__( 'Repeat', 'parallax-frame-pro' ),
	'section'  	=> 'parallax_frame_featured_content_background_settings',
	'settings' 	=> 'parallax_frame_theme_options[featured_content_background_repeat]',
	'type'	  	=> 'radio',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[featured_content_background_attachment]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_background_attachment'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$parallax_frame_featured_content_background_attachment_options = parallax_frame_featured_content_background_attachment_options();
$choices = array();
foreach ( $parallax_frame_featured_content_background_attachment_options as $parallax_frame_featured_content_background_attachment_option ) {
	$choices[$parallax_frame_featured_content_background_attachment_option['value']] = $parallax_frame_featured_content_background_attachment_option['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[featured_content_background_attachment]', array(
	'choices'  	=> $choices,
	'label'    	=> esc_html__( 'Attachment', 'parallax-frame-pro' ),
	'section'  	=> 'parallax_frame_featured_content_background_settings',
	'settings' 	=> 'parallax_frame_theme_options[featured_content_background_attachment]',
	'type'	  	=> 'radio',
) );