<?php
/**
 * Implement Default Theme/Customizer Options
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */


/**
 * Returns the default options for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_get_default_theme_options() {
	$theme_data = wp_get_theme();

	$default_theme_options = array(
		//Site Title an Tagline
		'hide_tagline'                                     => 1,
		'move_title_tagline'                               => 0,

		//Layout
		'theme_layout'                                     => 'right-sidebar',
		'woocommerce_layout'                               => 'right-sidebar',
		'content_layout'                                   => 'excerpt-image-left',
		'single_post_image_layout'                         => 'disabled',

		//Header Image
		'enable_featured_header_image'                     => 'exclude-home-page-post',
		'featured_image_size'                              => 'full',
		'featured_header_title'                            => esc_html( get_bloginfo( 'name') ),
		'featured_header_content'                          => esc_html( get_bloginfo( 'description' ) ),
		'featured_header_button_text'                      => esc_html__( 'View More', 'parallax-frame-pro' ),
		'featured_header_button_link'                      => '#',
		'featured_header_button_target'                    => 0,

		//Breadcrumb Options
		'breadcumb_option'                                 => 0,
		'breadcumb_on_homepage'                            => 0,
		'breadcumb_seperator'                              => '&raquo;',

		//Comment Options
		'comment_option'                                   => 'use-wordpress-setting',
		'disable_notes'                                    => 0,
		'disable_website_field'                            => 0,

		//Custom CSS
		'custom_css'                                       => '',

		//Scrollup Options
		'disable_scrollup'                                 => 0,

		//Excerpt Options
		'excerpt_length'                                   => '40',
		'excerpt_more_text'                                => esc_html__( 'Read More ...', 'parallax-frame-pro' ),

		//Fixed Header Top Options
		'primary_menu_disable'                             => 0,
		'disable_primary_search'                           => 1,

		// Header Top Widget Area Options
		'enable_header_top'                                => 'homepage',

		//Homepage / Frontpage Settings
		'front_page_category'                              => '0',

		//Pagination Options
		'pagination_type'                                  => 'default',

		//Promotion Headline Options
		'promotion_headline_option'                        => 'homepage',
		'promotion_headline'                               => esc_html__( 'Parallax Frame Pro WordPress Theme', 'parallax-frame-pro' ),
		'promotion_subheadline'                            => esc_html__( 'This is promotion headline. You can edit this from Appearance -> Customize -> Theme Options -> Promotion Headline Options', 'parallax-frame-pro' ),
		'promotion_headline_button'                        => esc_html__( 'Buy Now', 'parallax-frame-pro' ),
		'promotion_headline_url'                           => esc_url( 'https://catchthemes.com/' ),
		'promotion_headline_target'                        => 1,

		//Search Options
		'search_text'                                      => esc_html__( 'Search...', 'parallax-frame-pro' ),

		//Single Post Navigation
		'disable_single_post_navigation'                   => 0,

		//Feed Redirect
		'feed_redirect'                                    => '',

		//Font Family Options
		'body_font'                                        => 'open-sans',
		'title_font'                                       => 'open-sans',
		'tagline_font'                                     => 'open-sans',
		'content_title_font'                               => 'open-sans',
		'content_font'                                     => 'open-sans',
		'headings_font'                                    => 'open-sans',
		'reset_typography'                                 => 0,

		//Footer Editor Options
		'footer_top_content'                              => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved.', '1: Year, 2: Site Title with home URL', 'parallax-frame-pro' ), '[the-year]', '[site-link]' ),
		'footer_bottom_content'                             => esc_html__( 'Theme', 'parallax-frame-pro') . ': ' .  '<a target="_blank" href="'. esc_url( $theme_data->get( 'ThemeURI' ) ) .'">'. esc_attr( $theme_data->get( 'Name' ) ) .'</a>',
		'reset_footer_content'                             => 0,

		//Update Notifier
		'update_notifier'                                  => 0,

		//WooCommerce Options
		'disable_product_gallery_zoom'                     => 0,
		'disable_product_gallery_lightbox'                 => 0,
		'disable_product_gallery_slider'                   => 0,

		//Basic Color Options
		'color_scheme'                                     => 'light',
		'background_color'                                 => '#ffffff',
		'text_color'                                       => '#404040',
		'link_color'                                       => '#e8554e',
		'link_hover_color'                                 => '#404040',

		//Header Color Options
		'header_textcolor'                                 => '#ffffff',
		'header_background_color'                          => '#000000',
		'site_title_hover_color'                           => '#e8554e',
		'tagline_color'                                    => '#dddddd',

		//Content Color Options
		'content_wrapper_background_color'                 => '#ffffff',
		'content_background_color'                         => '#ffffff',
		'content_title_color'                              => '#404040',
		'content_title_hover_color'                        => '#e8554e',
		'content_meta_color'                               => '#767676',
		'content_meta_hover_color'                         => '#e8554e',

		//Sidebar Color Options
		'sidebar_background_color'                         => '#ffffff',
		'sidebar_widget_title_color'                       => '#404040',
		'sidebar_widget_text_color'                        => '#404040',
		'sidebar_widget_link_color'                        => '#767676',
		'sidebar_widget_link_hover_color'                  => '#e8554e',

		//Pagination Color Options
		'pagination_background_color'                      => '#ffffff',
		'pagination_link_color'                            => '#e8554e',
		'pagination_text_color'                            => '#404040',
		'pagination_border_color'                          => '#e8554e',
		'pagination_hover_background_color'                => '#e8554e',
		'pagination_hover_link_color'                      => '#ffffff',
		'pagination_hover_border_color'                    => '#e8554e',


		//Footer Color Options
		'footer_background_color'                          => '#000000',
		'footer_text_color'                                => '#dddddd',
		'footer_link_color'                                => '#ffffff',
		'footer_link_hover_color'                          => '#dddddd',
		'footer_sidebar_area_background_color'             => '#222222',
		'footer_sidebar_area_background_image'			   => get_template_directory_uri() . '/images/gallery/supplementary-bg.jpg',
		'footer_widget_title_color'                        => '#ffffff',
		'footer_widget_text_color'                         => '#dddddd',
		'footer_widget_link_color'                         => '#ffffff',
		'footer_widget_link_hover_color'                   => '#dddddd',

		//Promotion Headline Color Options
		'promotion_headline_background_color'              => '#ffffff',
		'promotion_headline_text_color'                    => '#404040',
		'promotion_headline_link_color'                    => '#e8554e',
		'promotion_headline_link_hover_color'              => '#404040',
		'promotion_headline_button_background_color'       => '#e8554e',
		'promotion_headline_button_link_color'             => '#ffffff',
		'promotion_headline_button_border_color'           => '#e8554e',
		'promotion_headline_button_hover_background_color' => '#ffffff',
		'promotion_headline_button_hover_link_color'       => '#e8554e',
		'promotion_headline_button_hover_border_color'     => '#e8554e',

		//Scrollup Color Options
		'scrollup_background_color'                        => '#ffffff',
		'scrollup_text_color'                              => '#e8554e',
		'scrollup_border_color'                            => '#e8554e',
		'scrollup_hover_background_color'                  => '#e8554e',
		'scrollup_hover_text_color'                        => '#ffffff',
		'scrollup_hover_border_color'                      => '#e8554e',

		//Header Highlight Content Color Options
		'header_highlight_background_color'                => '#404040',
		'header_highlight_title_color'                     => '#ffffff',
		'header_highlight_title_hover_color'               => '#e8554e',
		'header_highlight_text_color'                      => '#ffffff',
		'header_highlight_link_color'                      => '#ffffff',
		'header_highlight_link_hover_color'                => '#e8554e',
		'header_highlight_meta_color'                      => '#ffffff',
		'header_highlight_meta_hover_color'                => '#e8554e',

		//Slider Color Options
		'slider_background_color'                          => '#000000',
		'slider_text_color'                                => '#ffffff',
		'slider_link_color'                                => '#ffffff',
		'slider_link_hover_color'                          => '#ffffff',
		'slider_button_background_color'                   => 'transparent',
		'slider_button_text_color'                         => '#ffffff',
		'slider_button_border_color'                       => '#ffffff',
		'slider_button_hover_background_color'             => '#e8554e',
		'slider_button_hover_text_color'                   => '#ffffff',
		'slider_button_hover_border_color'                 => '#e8554e',

		//Hero Conent Color Options
		'hero_content_background_color'                    => 'transparent',
		'hero_content_title_color'                         => '#404040',
		'hero_content_text_color'                          => '#404040',
		'hero_content_link_color'                          => '#e8554e',
		'hero_content_link_hover_color'                    => '#404040',

		//Featured Content Color Options
		'featured_content_background_color'                => 'transparent',
		'featured_content_title_color'                     => '#ffffff',
		'featured_content_text_color'                      => '#ffffff',
		'featured_content_link_color'                      => '#e8554e',
		'featured_content_link_hover_color'                => '#ffffff',

		//Primary Menu Color Options
		'menu_background_color'                            => 'transparent',
		'menu_color'                                       => '#ffffff',
		'hover_active_background_color'                    => 'transparent',
		'hover_active_text_color'                          => '#e8554e',
		'sub_menu_background_color'                        => '#444444',
		'sub_menu_text_color'                              => '#ffffff',
		'sub_menu_hover_background_color'                  => '#444444',
		'sub_menu_hover_text_color'                        => '#e8554e',

		//Secondary Menu Color Options
		'secondary_menu_anchor_background_color'            => 'transparent',
		'secondary_menu_anchor_link_color'                  => '#ffffff',
		'secondary_menu_hover_anchor_background_color'      => 'transparent',
		'secondary_menu_hover_anchor_link_color'            => '#e8554e',

		//Footer Menu Color Options
		'footer_menu_background_color'                     => 'transparent',
		'footer_menu_color'                                => '#ffffff',
		'footer_hover_active_background_color'             => 'transparent',
		'footer_hover_active_text_color'                   => '#e8554e',

		//Header Highlight Content Options
		'header_highlight_content_option'                  => 'homepage',
		'header_highlight_content_type'                    => 'demo-header-highlight-content',
		'header_highlight_content_headline'                => '',
		'header_highlight_content_subheadline'             => '',
		'header_highlight_content_number'                  => '5',
		'header_highlight_content_select_category'         => '0',
		'header_highlight_content_show'                    => 'hide-content',
		'header_highlight_content_hide_category'           => 0,
		'header_highlight_content_hide_tags'               => 1,
		'header_highlight_content_hide_author'             => 1,
		'header_highlight_content_hide_date'               => 0,

		//Featured Slider Options
		'featured_slider_option'                           => 'homepage',
		'featured_slider_image_loader'                     => 'true',
		'featured_slider_transition_effect'                => 'fadeout',
		'featured_slider_transition_delay'                 => '4',
		'featured_slider_transition_length'                => '1',
		'featured_slider_type'                             => 'demo-featured-slider',
		'featured_slider_number'                           => '4',
		'featured_slider_select_category'                  => '0',
		'exclude_slider_post'                              => 0,

		//Hero Content Options
		'hero_content_option'                              => 'homepage',
		'hero_content_type'                                => 'demo-hero-content',
		'hero_content_number'                              => '1',
		'hero_content_enable_title'                        => 1,
		'hero_content_show'                                => 'excerpt',
		'hero_content_select_category'                     => '0',
		'disable_read_more'                                => 0,

		//Featured Content Options
		'featured_content_option'                          => 'homepage',
		'featured_content_layout'                          => 'layout-three',
		'featured_content_position'                        => 0,
		'featured_content_slider'                          => 1,
		'featured_content_headline'                        => '',
		'featured_content_subheadline'                     => '',
		'featured_content_type'                            => 'demo-featured-content',
		'featured_content_number'                          => '4',
		'featured_content_enable_title'                    => 1,
		'featured_content_show'                            => 'hide-content',
		'featured_content_select_category'                 => '0',

		'featured_content_background_image'                => get_template_directory_uri() . '/images/gallery/bg-featured-content.jpg',
		'featured_content_background_display_position'     => 'bottom',
		'featured_content_background_repeat'               => 'no-repeat',
		'featured_content_background_attachment'           => 'fixed',

		//Portfolio
		'portfolio_option'                                 => 'homepage',
		'portfolio_layout'                                 => 'layout-four',
		'portfolio_position'                               => 0,
		'portfolio_slider'                                 => 1,
		'portfolio_headline'                               => '',
		'portfolio_subheadline'                            => '',
		'portfolio_type'                                   => 'demo-portfolio',
		'portfolio_number'                                 => '4',
		'portfolio_enable_title'                           => 1,
		'portfolio_select_category'                        => '0',
		'portfolio_hide_category'                          => 0,
		'portfolio_hide_tags'                              => 1,
		'portfolio_hide_author'                            => 1,
		'portfolio_hide_date'                              => 0,

		//Logo Slider
		'logo_slider_option'                               => 'homepage',
		'logo_slider_type'                                 => 'demo',
		'logo_slider_visible_items'                        => '4',
		'logo_slider_transition_delay'                     => '4',
		'logo_slider_transition_length'                    => '1',
		'logo_slider_title'                                => '',
		'logo_slider_number'                               => '5',
		'logo_slider_select_category'                      => '0',
		'logo_slider_bg'                                   => get_template_directory_uri() . '/images/gallery/bg-logo-slider.jpg',

		//Social Links
		'social_icon_size'                                 => '20',
		'custom_social_icons'                              => '1',

		//Reset all settings
		'reset_all_settings'                               => 0,
	);

	return apply_filters( 'parallax_frame_default_theme_options', $default_theme_options );
}



/**
 * Returns an array of color schemes registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_color_schemes() {
	$options = array(
		'light' => array(
			'value' 				=> 'light',
			'label' 				=> esc_html__( 'Light', 'parallax-frame-pro' ),
		),
		'dark' => array(
			'value' 				=> 'dark',
			'label' 				=> esc_html__( 'Dark', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_color_schemes', $options );
}


/**
 * Returns an array of layout options registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_layouts() {
	$options = array(
		'left-sidebar'          => esc_html__( 'Primary Sidebar, Content', 'parallax-frame-pro' ),
		'right-sidebar'         => esc_html__( 'Content, Primary Sidebar', 'parallax-frame-pro' ),
		'no-sidebar'            => esc_html__( 'No Sidebar ( Content Width )', 'parallax-frame-pro' ),
		'no-sidebar-full-width' => esc_html__( 'No Sidebar ( Full Width )', 'parallax-frame-pro' ),
	);
	return apply_filters( 'parallax_frame_layouts', $options );
}


/**
 * Returns an array of content layout options registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_get_archive_content_layout() {
	$options = array(
		'excerpt-image-left'  => esc_html__( 'Show Excerpt (Image Left)', 'parallax-frame-pro' ),
		'excerpt-image-right' => esc_html__( 'Show Excerpt (Image Right)', 'parallax-frame-pro' ),
		'excerpt-image-top'   => esc_html__( 'Show Excerpt (Image Top)', 'parallax-frame-pro' ),
		'full-content'        => esc_html__( 'Show Full Content (No Featured Image)', 'parallax-frame-pro' ),
	);
	return apply_filters( 'parallax_frame_get_archive_content_layout', $options );
}


/**
 * Returns an array of feature header enable options
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_enable_featured_header_image_options() {
	$options = array(
		'homepage' 		=> array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Frontpage', 'parallax-frame-pro' ),
		),
		'exclude-home' 		=> array(
			'value'	=> 'exclude-home',
			'label' => esc_html__( 'Excluding Homepage', 'parallax-frame-pro' ),
		),
		'exclude-home-page-post' 	=> array(
			'value' => 'exclude-home-page-post',
			'label' => esc_html__( 'Excluding Homepage, Page/Post Featured Image', 'parallax-frame-pro' ),
		),
		'entire-site' 	=> array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'parallax-frame-pro' ),
		),
		'entire-site-page-post' 	=> array(
			'value' => 'entire-site-page-post',
			'label' => esc_html__( 'Entire Site, Page/Post Featured Image', 'parallax-frame-pro' ),
		),
		'pages-posts' 	=> array(
			'value' => 'pages-posts',
			'label' => esc_html__( 'Pages and Posts', 'parallax-frame-pro' ),
		),
		'disabled'		=> array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_enable_featured_header_image_options', $options );
}


/**
 * Returns an array of feature image size
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_featured_image_size_options() {
	$all_sizes = parallax_frame_get_additional_image_sizes();

	foreach ($all_sizes as $key => $value) {
		$options[$key] = esc_html( $key ).' ('.$value['width'].'x'.$value['height'].')';
	}

	$options['full'] = esc_html__( 'Full size', 'parallax-frame-pro' );

	return apply_filters( 'parallax_frame_featured_image_size_options', $options );
}


/**
 * Returns an array of content and slider layout options registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_featured_slider_content_options() {
	$options = array(
		'homepage'    => array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Frontpage', 'parallax-frame-pro' ),
		),
		'entire-site' => array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'parallax-frame-pro' ),
		),
		'disabled'	  => array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_featured_slider_content_options', $options );
}


/**
 * Returns an array of hero content types registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_hero_content_types() {
	$options = array(
		'demo-hero-content' => array(
			'value' => 'demo-hero-content',
			'label' => esc_html__( 'Demo Content', 'parallax-frame-pro' ),
		),
		'hero-post-content' => array(
			'value' => 'hero-post-content',
			'label' => esc_html__( 'Post Content', 'parallax-frame-pro' ),
		),
		'hero-page-content' => array(
			'value' => 'hero-page-content',
			'label' => esc_html__( 'Page Content', 'parallax-frame-pro' ),
		),
		'hero-category-content' => array(
			'value' => 'hero-category-content',
			'label' => esc_html__( 'Category Content', 'parallax-frame-pro' ),
		),
		'hero-custom-content' => array(
			'value' => 'hero-custom-content',
			'label' => esc_html__( 'Custom Content', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_hero_content_types', $options );
}


/**
 * Returns an array of feature content types registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_featured_content_types() {
	$options = array(
		'demo-featured-content' => array(
			'value' => 'demo-featured-content',
			'label' => esc_html__( 'Demo Featured Content', 'parallax-frame-pro' ),
		),
		'featured-post-content' => array(
			'value' => 'featured-post-content',
			'label' => esc_html__( 'Featured Post Content', 'parallax-frame-pro' ),
		),
		'featured-page-content' => array(
			'value' => 'featured-page-content',
			'label' => esc_html__( 'Featured Page Content', 'parallax-frame-pro' ),
		),
		'featured-category-content' => array(
			'value' => 'featured-category-content',
			'label' => esc_html__( 'Featured Category Content', 'parallax-frame-pro' ),
		),
		'featured-image-content' => array(
			'value' => 'featured-image-content',
			'label' => esc_html__( 'Featured Image Content', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_featured_content_types', $options );
}


/**
 * Returns an array of featured content options registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_featured_content_layout_options() {
	$options = array(
		'layout-three' => array(
			'value'	=> 'layout-three',
			'label' => esc_html__( '3 columns', 'parallax-frame-pro' ),
		),
		'layout-four'  => array(
			'value' => 'layout-four',
			'label' => esc_html__( '4 columns', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_featured_content_layout_options', $options );
}


/**
 * Returns an array of featured content show registered for parallaxframe.
 *
 * @since parallaxframe 1.6
 */
function parallax_frame_featured_content_show() {
	$options = array(
		'excerpt'      => array(
			'value'	=> 'excerpt',
			'label' => esc_html__( 'Show Excerpt', 'parallax-frame-pro' ),
		),
		'full-content' => array(
			'value' => 'full-content',
			'label' => esc_html__( 'Show Full Content', 'parallax-frame-pro' ),
		),
		'hide-content' => array(
			'value' => 'hide-content',
			'label' => esc_html__( 'Hide Content', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_featured_content_show', $options );
}


/**
 * Returns an array of header highlight content types registered for Parallax Frame.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_header_highlight_content_types() {
	$options = array(
		'demo-header-highlight-content' => array(
			'value' => 'demo-header-highlight-content',
			'label' => __( 'Demo Content', 'parallax-frame-pro' ),
		),
		'header-highlight-post-content' => array(
			'value' => 'header-highlight-post-content',
			'label' => __( 'Post Content', 'parallax-frame-pro' ),
		),
		'header-highlight-page-content' => array(
			'value' => 'header-highlight-page-content',
			'label' => __( 'Page Content', 'parallax-frame-pro' ),
		),
		'header-highlight-category-content' => array(
			'value' => 'header-highlight-category-content',
			'label' => __( 'Category Content', 'parallax-frame-pro' ),
		),
		'header-highlight-image-content' => array(
			'value' => 'header-highlight-image-content',
			'label' => __( 'Image Content', 'parallax-frame-pro' ),
		),
		'header-highlight-embed-content' => array(
			'value' => 'header-highlight-embed-content',
			'label' => __( 'Embed Content', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_header_highlight_content_types', $options );
}


/**
 * Returns an array of feature slider types registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_featured_slider_types() {
	$options = array(
		'demo-featured-slider' => array(
			'value' => 'demo-featured-slider',
			'label' => esc_html__( 'Demo Featured Slider', 'parallax-frame-pro' ),
		),
		'featured-post-slider' => array(
			'value' => 'featured-post-slider',
			'label' => esc_html__( 'Featured Post Slider', 'parallax-frame-pro' ),
		),
		'featured-page-slider' => array(
			'value' => 'featured-page-slider',
			'label' => esc_html__( 'Featured Page Slider', 'parallax-frame-pro' ),
		),
		'featured-category-slider' => array(
			'value' => 'featured-category-slider',
			'label' => esc_html__( 'Featured Category Slider', 'parallax-frame-pro' ),
		),
		'featured-image-slider' => array(
			'value' => 'featured-image-slider',
			'label' => esc_html__( 'Featured Image Slider', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_featured_slider_types', $options );
}


/**
 * Returns an array of feature slider transition effects
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_featured_slider_transition_effects() {
	$options = array(
		'fade' 		=> array(
			'value'	=> 'fade',
			'label' => esc_html__( 'Fade', 'parallax-frame-pro' ),
		),
		'fadeout' 	=> array(
			'value'	=> 'fadeout',
			'label' => esc_html__( 'Fade Out', 'parallax-frame-pro' ),
		),
		'none' 		=> array(
			'value' => 'none',
			'label' => esc_html__( 'None', 'parallax-frame-pro' ),
		),
		'scrollHorz'=> array(
			'value' => 'scrollHorz',
			'label' => esc_html__( 'Scroll Horizontal', 'parallax-frame-pro' ),
		),
		'scrollVert'=> array(
			'value' => 'scrollVert',
			'label' => esc_html__( 'Scroll Vertical', 'parallax-frame-pro' ),
		),
		'flipHorz'	=> array(
			'value' => 'flipHorz',
			'label' => esc_html__( 'Flip Horizontal', 'parallax-frame-pro' ),
		),
		'flipVert'	=> array(
			'value' => 'flipVert',
			'label' => esc_html__( 'Flip Vertical', 'parallax-frame-pro' ),
		),
		'tileSlide'	=> array(
			'value' => 'tileSlide',
			'label' => esc_html__( 'Tile Slide', 'parallax-frame-pro' ),
		),
		'tileBlind'	=> array(
			'value' => 'tileBlind',
			'label' => esc_html__( 'Tile Blind', 'parallax-frame-pro' ),
		),
		'shuffle'	=> array(
			'value' => 'shuffle',
			'label' => esc_html__( 'Shuffle', 'parallax-frame-pro' ),
		)
	);

	return apply_filters( 'parallax_frame_featured_slider_transition_effects', $options );
}


/**
 * Returns an array of featured slider image loader options
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_featured_slider_image_loader() {
	$options = array(
		'true' => array(
			'value' 				=> 'true',
			'label' 				=> esc_html__( 'True', 'parallax-frame-pro' ),
		),
		'wait' => array(
			'value' 				=> 'wait',
			'label' 				=> esc_html__( 'Wait', 'parallax-frame-pro' ),
		),
		'false' => array(
			'value' 				=> 'false',
			'label' 				=> esc_html__( 'False', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_featured_slider_image_loader', $options );
}


/**
 * Returns an array of portfolio types registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_portfolio_types() {
	$options = array(
		'demo-portfolio' => array(
			'value' => 'demo-portfolio',
			'label' => esc_html__( 'Demo Portfolio', 'parallax-frame-pro' ),
		),
		'post-portfolio' => array(
			'value' => 'post-portfolio',
			'label' => esc_html__( 'Post Portfolio', 'parallax-frame-pro' ),
		),
		'page-portfolio' => array(
			'value' => 'page-portfolio',
			'label' => esc_html__( 'Page Portfolio', 'parallax-frame-pro' ),
		),
		'category-portfolio' => array(
			'value' => 'category-portfolio',
			'label' => esc_html__( 'Category Portfolio', 'parallax-frame-pro' ),
		),
		'image-portfolio' => array(
			'value' => 'image-portfolio',
			'label' => esc_html__( 'Image Portfolio', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_portfolio_types', $options );
}


/**
 * Returns an array of feature content types registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_logo_slider_types() {
	$options = array(
		'demo' => array(
			'value' => 'demo',
			'label' => esc_html__( 'Demo Logo Slider', 'parallax-frame-pro' ),
		),
		'post' => array(
			'value' => 'post',
			'label' => esc_html__( 'Post Logo Slider', 'parallax-frame-pro' ),
		),
		'page' => array(
			'value' => 'page',
			'label' => esc_html__( 'Page Logo Slider', 'parallax-frame-pro' ),
		),
		'category' => array(
			'value' => 'category',
			'label' => esc_html__( 'Category Logo Slider', 'parallax-frame-pro' ),
		),
		'image' => array(
			'value' => 'image',
			'label' => esc_html__( 'Image Logo Slider', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_logo_slider_types', $options );
}


/**
 * Returns an array of color schemes registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_get_pagination_types() {
	$options = array(
		'default' => array(
			'value' => 'default',
			'label' => esc_html__( 'Default(Older Posts/Newer Posts)', 'parallax-frame-pro' ),
		),
		'numeric' => array(
			'value' => 'numeric',
			'label' => esc_html__( 'Numeric', 'parallax-frame-pro' ),
		),
		'infinite-scroll-click' => array(
			'value' => 'infinite-scroll-click',
			'label' => esc_html__( 'Infinite Scroll (Click)', 'parallax-frame-pro' ),
		),
		'infinite-scroll-scroll' => array(
			'value' => 'infinite-scroll-scroll',
			'label' => esc_html__( 'Infinite Scroll (Scroll)', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_get_pagination_types', $options );
}


/**
 * Returns an array of content featured image size.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_single_post_image_layout_options() {
	$all_sizes = parallax_frame_get_additional_image_sizes();

	foreach ($all_sizes as $key => $value) {
		$options[$key] = esc_html( $key ).' ('.$value['width'].'x'.$value['height'].')';
	}

	$options['disabled'] = esc_html__( 'Disabled', 'parallax-frame-pro' );
	$options['full']     = esc_html__( 'Full size', 'parallax-frame-pro' );

	return apply_filters( 'parallax_frame_single_post_image_layout_options', $options );
}


/**
 * Returns an array of comment options for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_comment_options() {
	$options = array(
		'use-wordpress-setting' => array(
			'value' => 'use-wordpress-setting',
			'label' => esc_html__( 'Use WordPress Setting', 'parallax-frame-pro' ),
		),
		'disable-in-pages' => array(
			'value' => 'disable-in-pages',
			'label' => esc_html__( 'Disable in Pages', 'parallax-frame-pro' ),
		),
		'disable-completely' => array(
			'value' => 'disable-completely',
			'label' => esc_html__( 'Disable Completely', 'parallax-frame-pro' ),
		),
	);

	return apply_filters( 'parallax_frame_comment_options', $options );
}


/**
 * Returns an array of avaliable fonts registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_avaliable_fonts() {
	$options = array(
		'arial-black' => array(
			'value' => 'arial-black',
			'label' => '"Arial Black", Gadget, sans-serif',
		),
		'allan' => array(
			'value' => 'allan',
			'label' => '"Allan", sans-serif',
		),
		'allerta' => array(
			'value' => 'allerta',
			'label' => '"Allerta", sans-serif',
		),
		'amaranth' => array(
			'value' => 'amaranth',
			'label' => '"Amaranth", sans-serif',
		),
		'arial' => array(
			'value' => 'arial',
			'label' => 'Arial, Helvetica, sans-serif',
		),
		'bitter' => array(
			'value' => 'bitter',
			'label' => '"Bitter", sans-serif',
		),
		'cabin' => array(
			'value' => 'cabin',
			'label' => '"Cabin", sans-serif',
		),
		'cantarell' => array(
			'value' => 'cantarell',
			'label' => '"Cantarell", sans-serif',
		),
		'century-gothic' => array(
			'value' => 'century-gothic',
			'label' => '"Century Gothic", sans-serif',
		),
		'courier-new' => array(
			'value' => 'courier-new',
			'label' => '"Courier New", Courier, monospace',
		),
		'crimson-text' => array(
			'value' => 'crimson-text',
			'label' => '"Crimson Text", sans-serif',
		),
		'cuprum' => array(
			'value' => 'cuprum',
			'label' => '"Cuprum", sans-serif',
		),
		'dancing-script' => array(
			'value' => 'dancing-script',
			'label' => '"Dancing Script", sans-serif',
		),
		'droid-sans' => array(
			'value' => 'droid-sans',
			'label' => '"Droid Sans", sans-serif',
		),
		'droid-serif' => array(
			'value' => 'droid-serif',
			'label' => '"Droid Serif", sans-serif',
		),
		'exo' => array(
			'value' => 'exo',
			'label' => '"Exo", sans-serif',
		),
		'exo-2' => array(
			'value' => 'exo-2',
			'label' => '"Exo 2", sans-serif',
		),
		'georgia' => array(
			'value' => 'georgia',
			'label' => 'Georgia, "Times New Roman", Times, serif',
		),
		'helvetica' => array(
			'value' => 'helvetica',
			'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
		),
		'helvetica-neue' => array(
			'value' => 'helvetica-neue',
			'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
		),
		'istok-web' => array(
			'value' => 'istok-web',
			'label' => '"Istok Web", sans-serif',
		),
		'impact' => array(
			'value' => 'impact',
			'label' => 'Impact, Charcoal, sans-serif',
		),
		'lato' => array(
			'value' => 'lato',
			'label' => '"Lato", sans-serif',
		),
		'lucida-sans-unicode' => array(
			'value' => 'lucida-sans-unicode',
			'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		),
		'lucida-grande' => array(
			'value' => 'lucida-grande',
			'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
		),
		'lobster' => array(
			'value' => 'lobster',
			'label' => '"Lobster", sans-serif',
		),
		'lora' => array(
			'value' => 'lora',
			'label' => '"Lora", serif',
		),
		'monaco' => array(
			'value' => 'monaco',
			'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
		),
		'montserrat' => array(
			'value' => 'montserrat',
			'label' => '"Montserrat", sans-serif',
		),
		'nobile' => array(
			'value' => 'nobile',
			'label' => '"Nobile", sans-serif',
		),
		'noto-serif' => array(
			'value' => 'noto-serif',
			'label' => '"Noto Serif", serif',
		),
		'neuton' => array(
			'value' => 'neuton',
			'label' => '"Neuton", serif',
		),
		'open-sans' => array(
			'value' => 'open-sans',
			'label' => '"Open Sans", sans-serif',
		),
		'oswald' => array(
			'value' => 'oswald',
			'label' => '"Oswald", sans-serif',
		),
		'palatino' => array(
			'value' => 'palatino',
			'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
		),
		'patua-one' => array(
			'value' => 'patua-one',
			'label' => '"Patua One", sans-serif',
		),
		'playfair-display' => array(
			'value' => 'playfair-display',
			'label' => '"Playfair Display", sans-serif',
		),
		'pt-sans' => array(
			'value' => 'pt-sans',
			'label' => '"PT Sans", sans-serif',
		),
		'pt-serif' => array(
			'value' => 'pt-serif',
			'label' => '"PT Serif", serif',
		),
		'quattrocento-sans' => array(
			'value' => 'quattrocento-sans',
			'label' => '"Quattrocento Sans", sans-serif',
		),
		'roboto' => array(
			'value' => 'roboto',
			'label' => '"Roboto", sans-serif',
		),
		'roboto-slab' => array(
			'value' => 'roboto-slab',
			'label' => '"Roboto Slab", serif',
		),
		'sans-serif' => array(
			'value' => 'sans-serif',
			'label' => 'Sans Serif, Arial',
		),
		'source-sans-pro' => array(
			'value' => 'source-sans-pro',
			'label' => '"Source Sans Pro", sans-serif',
		),
		'tahoma' => array(
			'value' => 'tahoma',
			'label' => 'Tahoma, Geneva, sans-serif',
		),
		'trebuchet-ms' => array(
			'value' => 'trebuchet-ms',
			'label' => '"Trebuchet MS", "Helvetica", sans-serif',
		),
		'times-new-roman' => array(
			'value' => 'times-new-roman',
			'label' => '"Times New Roman", Times, serif',
		),
		'ubuntu' => array(
			'value' => 'ubuntu',
			'label' => '"Ubuntu", sans-serif',
		),
		'verdana' => array(
			'value' => 'verdana',
			'label' => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz' => array(
			'value' => 'yanone-kaffeesatz',
			'label' => '"Yanone Kaffeesatz", sans-serif',
		),
	);

	return apply_filters( 'parallax_frame_avaliable_fonts', $options );
}


/**
 * Returns list of social icons currently supported
 *
 * @since Parallax Frame 1.0
*/
function parallax_frame_get_social_icons_list() {
	$options = array(
		'facebook_link'		=> array(
			'genericon_class' 	=> 'facebook-alt',
			'label' 			=> esc_html__( 'Facebook', 'parallax-frame-pro' )
			),
		'twitter_link'		=> array(
			'genericon_class' 	=> 'twitter',
			'label' 			=> esc_html__( 'Twitter', 'parallax-frame-pro' )
			),
		'googleplus_link'	=> array(
			'genericon_class' 	=> 'googleplus-alt',
			'label' 			=> esc_html__( 'Googleplus', 'parallax-frame-pro' )
			),
		'email_link'		=> array(
			'genericon_class' 	=> 'mail',
			'label' 			=> esc_html__( 'Email', 'parallax-frame-pro' )
			),
		'feed_link'			=> array(
			'genericon_class' 	=> 'feed',
			'label' 			=> esc_html__( 'Feed', 'parallax-frame-pro' )
			),
		'wordpress_link'	=> array(
			'genericon_class' 	=> 'wordpress',
			'label' 			=> esc_html__( 'WordPress', 'parallax-frame-pro' )
			),
		'github_link'		=> array(
			'genericon_class' 	=> 'github',
			'label' 			=> esc_html__( 'GitHub', 'parallax-frame-pro' )
			),
		'linkedin_link'		=> array(
			'genericon_class' 	=> 'linkedin',
			'label' 			=> esc_html__( 'LinkedIn', 'parallax-frame-pro' )
			),
		'pinterest_link'	=> array(
			'genericon_class' 	=> 'pinterest',
			'label' 			=> esc_html__( 'Pinterest', 'parallax-frame-pro' )
			),
		'flickr_link'		=> array(
			'genericon_class' 	=> 'flickr',
			'label' 			=> esc_html__( 'Flickr', 'parallax-frame-pro' )
			),
		'vimeo_link'		=> array(
			'genericon_class' 	=> 'vimeo',
			'label' 			=> esc_html__( 'Vimeo', 'parallax-frame-pro' )
			),
		'youtube_link'		=> array(
			'genericon_class' 	=> 'youtube',
			'label' 			=> esc_html__( 'YouTube', 'parallax-frame-pro' )
			),
		'tumblr_link'		=> array(
			'genericon_class' 	=> 'tumblr',
			'label' 			=> esc_html__( 'Tumblr', 'parallax-frame-pro' )
			),
		'instagram_link'	=> array(
			'genericon_class' 	=> 'instagram',
			'label' 			=> esc_html__( 'Instagram', 'parallax-frame-pro' )
			),
		'polldaddy_link'	=> array(
			'genericon_class' 	=> 'polldaddy',
			'label' 			=> esc_html__( 'PollDaddy', 'parallax-frame-pro' )
			),
		'codepen_link'		=> array(
			'genericon_class' 	=> 'codepen',
			'label' 			=> esc_html__( 'CodePen', 'parallax-frame-pro' )
			),
		'path_link'			=> array(
			'genericon_class' 	=> 'path',
			'label' 			=> esc_html__( 'Path', 'parallax-frame-pro' )
			),
		'dribbble_link'		=> array(
			'genericon_class' 	=> 'dribbble',
			'label' 			=> esc_html__( 'Dribbble', 'parallax-frame-pro' )
			),
		'skype_link'		=> array(
			'genericon_class' 	=> 'skype',
			'label' 			=> esc_html__( 'Skype', 'parallax-frame-pro' )
			),
		'digg_link'			=> array(
			'genericon_class' 	=> 'digg',
			'label' 			=> esc_html__( 'Digg', 'parallax-frame-pro' )
			),
		'reddit_link'		=> array(
			'genericon_class' 	=> 'reddit',
			'label' 			=> esc_html__( 'Reddit', 'parallax-frame-pro' )
			),
		'stumbleupon_link'	=> array(
			'genericon_class' 	=> 'stumbleupon',
			'label' 			=> esc_html__( 'Stumbleupon', 'parallax-frame-pro' )
			),
		'pocket_link'		=> array(
			'genericon_class' 	=> 'pocket',
			'label' 			=> esc_html__( 'Pocket', 'parallax-frame-pro' ),
			),
		'dropbox_link'		=> array(
			'genericon_class' 	=> 'dropbox',
			'label' 			=> esc_html__( 'DropBox', 'parallax-frame-pro' ),
			),
		'spotify_link'		=> array(
			'genericon_class' 	=> 'spotify',
			'label' 			=> esc_html__( 'Spotify', 'parallax-frame-pro' ),
			),
		'foursquare_link'	=> array(
			'genericon_class' 	=> 'foursquare',
			'label' 			=> esc_html__( 'Foursquare', 'parallax-frame-pro' ),
			),
		'twitch_link'		=> array(
			'genericon_class' 	=> 'twitch',
			'label' 			=> esc_html__( 'Twitch', 'parallax-frame-pro' ),
			),
		'website_link'		=> array(
			'genericon_class' 	=> 'website',
			'label' 			=> esc_html__( 'Website', 'parallax-frame-pro' ),
			),
		'phone_link'		=> array(
			'genericon_class' 	=> 'phone',
			'label' 			=> esc_html__( 'Phone', 'parallax-frame-pro' ),
			),
		'handset_link'		=> array(
			'genericon_class' 	=> 'handset',
			'label' 			=> esc_html__( 'Handset', 'parallax-frame-pro' ),
			),
		'cart_link'			=> array(
			'genericon_class' 	=> 'cart',
			'label' 			=> esc_html__( 'Cart', 'parallax-frame-pro' ),
			),
		'cloud_link'		=> array(
			'genericon_class' 	=> 'cloud',
			'label' 			=> esc_html__( 'Cloud', 'parallax-frame-pro' ),
			),
		'link_link'		=> array(
			'genericon_class' 	=> 'link',
			'label' 			=> esc_html__( 'Link', 'parallax-frame-pro' ),
			),
	);

	return apply_filters( 'parallax_frame_social_icons_list', $options );
}


/**
 * Returns list of basic color options currently supported
 *
 * @since Parallax Frame Pro 1.0
*/
function parallax_frame_get_color_options( $filter ) {
	$options = array(); // Initialize options
	switch ( $filter ) {
		case 'color_headings':
			$options = array(
				'basic_color'              => esc_html__( 'Basic Color', 'parallax-frame-pro' ),
				'header_color'             => esc_html__( 'Header Color', 'parallax-frame-pro' ),
				'content_color'            => esc_html__( 'Content Color', 'parallax-frame-pro' ),
				'sidebar_color'            => esc_html__( 'Sidebar Color', 'parallax-frame-pro' ),
				'pagination_color'         => esc_html__( 'Pagination Color', 'parallax-frame-pro' ),
				'footer_color'             => esc_html__( 'Footer Color', 'parallax-frame-pro' ),
				'promotion_headline_color' => esc_html__( 'Promotion Headline Color', 'parallax-frame-pro' ),
				'scrollup_color'           => esc_html__( 'Scrollup Color', 'parallax-frame-pro' ),
				'header_highlight_color'   => esc_html__( 'Header Highlight Color', 'parallax-frame-pro' ),
				'slider_color'             => esc_html__( 'Slider Color', 'parallax-frame-pro' ),
				'hero_content_color'       => esc_html__( 'Hero Content Color', 'parallax-frame-pro' ),
				'featured_content_color'   => esc_html__( 'Featured Content Color', 'parallax-frame-pro' ),
				'menu_color'               => esc_html__( 'Primary Menu Color', 'parallax-frame-pro' ),
				'secondary_menu_color'     => esc_html__( 'Secondary Menu Color', 'parallax-frame-pro' ),
				'footer_menu_color'        => esc_html__( 'Footer Menu Color', 'parallax-frame-pro' ),
			);
			break;

		case 'basic_color':
			$options =	array(
				'text_color'       => esc_html__( 'Text Color', 'parallax-frame-pro' ),
				'link_color'       => esc_html__( 'Link Color', 'parallax-frame-pro' ),
				'link_hover_color' => esc_html__( 'Link Hover Color', 'parallax-frame-pro' ),
			);
			break;

		case 'header_color':
			$options = array(
				'header_background_color' => esc_html__( 'Header Background color', 'parallax-frame-pro' ),
				'site_title_hover_color'  => esc_html__( 'Site Title Hover Color', 'parallax-frame-pro' ),
				'tagline_color'           => esc_html__( 'Tagline Color', 'parallax-frame-pro' )
			);
			break;

		case 'content_color':
			$options =	array(
				'content_wrapper_background_color' => esc_html__( 'Wrapper Background Color', 'parallax-frame-pro' ),
				'content_background_color'         => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'content_title_color'              => esc_html__( 'Title Color', 'parallax-frame-pro' ),
				'content_title_hover_color'        => esc_html__( 'Title Hover Color', 'parallax-frame-pro' ),
				'content_meta_color'               => esc_html__( 'Meta Color', 'parallax-frame-pro' ),
				'content_meta_hover_color'         => esc_html__( 'Meta Hover Color', 'parallax-frame-pro' ),
			);
			break;

		case 'sidebar_color':
			$options = array(
				'sidebar_background_color'        => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'sidebar_widget_title_color'      => esc_html__( 'Widget Title Color', 'parallax-frame-pro' ),
				'sidebar_widget_text_color'       => esc_html__( 'Widget Text Color', 'parallax-frame-pro' ),
				'sidebar_widget_link_color'       => esc_html__( 'Widget Link Color', 'parallax-frame-pro' ),
				'sidebar_widget_link_hover_color' => esc_html__( 'Widget Link Hover Color', 'parallax-frame-pro' ),
				);
			break;

		case 'pagination_color':
			$options = array(
				'pagination_background_color'       => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'pagination_link_color'             => esc_html__( 'Link Color', 'parallax-frame-pro' ),
				'pagination_border_color'           => esc_html__( 'Border Color', 'parallax-frame-pro' ),
				'pagination_hover_background_color' => esc_html__( 'Hover Background Color', 'parallax-frame-pro' ),
				'pagination_hover_link_color'       => esc_html__( 'Hover Link Color', 'parallax-frame-pro' ),
				'pagination_hover_border_color'     => esc_html__( 'Hover Border Color', 'parallax-frame-pro' ),
				'pagination_text_color'             => esc_html__( 'Text Color', 'parallax-frame-pro' ),
			);
			break;

		case 'footer_color':
			$options = array(
				'footer_background_color'              => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'footer_text_color'                    => esc_html__( 'Text Color', 'parallax-frame-pro' ),
				'footer_link_color'                    => esc_html__( 'Link Color', 'parallax-frame-pro' ),
				'footer_link_hover_color'              => esc_html__( 'Link Hover Color', 'parallax-frame-pro' ),
				'footer_sidebar_area_background_color' => esc_html__( 'Sidebar Area Background Color', 'parallax-frame-pro' ),
				'footer_widget_title_color'            => esc_html__( 'Widget Title Color', 'parallax-frame-pro' ),
				'footer_widget_text_color'             => esc_html__( 'Widget Text Color', 'parallax-frame-pro' ),
				'footer_widget_link_color'             => esc_html__( 'Widget Link Color', 'parallax-frame-pro' ),
				'footer_widget_link_hover_color'       => esc_html__( 'Widget Link Hover Color', 'parallax-frame-pro' ),
			);
			break;

		case 'promotion_headline_color':
			$options = array(
				'promotion_headline_background_color'              => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'promotion_headline_text_color'                    => esc_html__( 'Text Color', 'parallax-frame-pro' ),
				'promotion_headline_link_color'                    => esc_html__( 'Link Color', 'parallax-frame-pro' ),
				'promotion_headline_link_hover_color'                    => esc_html__( 'Link Hover Color', 'parallax-frame-pro' ),
				'promotion_headline_button_background_color'       => esc_html__( 'Button Background Color', 'parallax-frame-pro' ),
				'promotion_headline_button_link_color'             => esc_html__( 'Button Link Color', 'parallax-frame-pro' ),
				'promotion_headline_button_border_color'             => esc_html__( 'Button Border Color', 'parallax-frame-pro' ),
				'promotion_headline_button_hover_background_color' => esc_html__( 'Button Hover Background Color', 'parallax-frame-pro' ),
				'promotion_headline_button_hover_link_color'       => esc_html__( 'Button Hover Link Color', 'parallax-frame-pro' ),
				'promotion_headline_button_hover_border_color'       => esc_html__( 'Button Hover Border Color', 'parallax-frame-pro' ),
			);
			break;

		case 'scrollup_color':
			$options = array(
				'scrollup_background_color'       => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'scrollup_text_color'             => esc_html__( 'Text Color', 'parallax-frame-pro' ),
				'scrollup_border_color'           => esc_html__( 'Border Color', 'parallax-frame-pro' ),
				'scrollup_hover_background_color' => esc_html__( 'Hover Background Color', 'parallax-frame-pro' ),
				'scrollup_hover_text_color'       => esc_html__( 'Hover Text Color', 'parallax-frame-pro' ),
				'scrollup_hover_border_color'     => esc_html__( 'Hover Border Color', 'parallax-frame-pro' ),
			);
			break;

		case 'header_highlight_color':
			$options = array(
				'header_highlight_background_color'  => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'header_highlight_title_color'       => esc_html__( 'Title Color', 'parallax-frame-pro' ),
				'header_highlight_title_hover_color' => esc_html__( 'Title Hover Color', 'parallax-frame-pro' ),
				'header_highlight_text_color'        => esc_html__( 'Text Color', 'parallax-frame-pro' ),
				'header_highlight_link_color'        => esc_html__( 'Link Color', 'parallax-frame-pro' ),
				'header_highlight_link_hover_color'  => esc_html__( 'Link Hover Color', 'parallax-frame-pro' ),
				'header_highlight_meta_color'        => esc_html__( 'Meta Color', 'parallax-frame-pro' ),
				'header_highlight_meta_hover_color'  => esc_html__( 'Meta Hover Color', 'parallax-frame-pro' ),
			);
			break;

		case 'slider_color':
			$options = array(
				'slider_background_color'              => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'slider_text_color'                    => esc_html__( 'Text Color', 'parallax-frame-pro' ),
				'slider_link_color'                    => esc_html__( 'Link Color', 'parallax-frame-pro' ),
				'slider_link_hover_color'              => esc_html__( 'Link Hover Color', 'parallax-frame-pro' ),
				'slider_button_background_color'       => esc_html__( 'Button Background Color', 'parallax-frame-pro' ),
				'slider_button_text_color'             => esc_html__( 'Button Text Color', 'parallax-frame-pro' ),
				'slider_button_border_color'           => esc_html__( 'Button Border Color', 'parallax-frame-pro' ),
				'slider_button_hover_background_color' => esc_html__( 'Button Hover Background Color', 'parallax-frame-pro' ),
				'slider_button_hover_text_color'       => esc_html__( 'Button Hover Text Color', 'parallax-frame-pro' ),
				'slider_button_hover_border_color'     => esc_html__( 'Button Hover Border Color', 'parallax-frame-pro' ),
				);
			break;

		case 'hero_content_color':
			$options = array(
				'hero_content_background_color' => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'hero_content_text_color'       => esc_html__( 'Text Color', 'parallax-frame-pro' ),
				'hero_content_title_color'      => esc_html__( 'Title Color', 'parallax-frame-pro' ),
				'hero_content_link_color'       => esc_html__( 'Link Color', 'parallax-frame-pro' ),
				'hero_content_link_hover_color' => esc_html__( 'Link Hover Color', 'parallax-frame-pro' ),
			);
			break;

		case 'featured_content_color':
			$options = array(
				'featured_content_background_color' => esc_html__( 'Background Color', 'parallax-frame-pro' ),
				'featured_content_title_color'      => esc_html__( 'Title Color', 'parallax-frame-pro' ),
				'featured_content_text_color'       => esc_html__( 'Text Color', 'parallax-frame-pro' ),
				'featured_content_link_color'       => esc_html__( 'Link Color', 'parallax-frame-pro' ),
				'featured_content_link_hover_color' => esc_html__( 'Link Hover Color', 'parallax-frame-pro' ),
			);
			break;

		case 'menu_color':
			$options = array(
				'menu_background_color'         => esc_html__( 'Menu Background color', 'parallax-frame-pro' ),
				'menu_color'                    => esc_html__( 'Menu Color', 'parallax-frame-pro' ),
				'hover_active_background_color' => esc_html__( 'Hover Active Background Color', 'parallax-frame-pro' ),
				'hover_active_text_color'       => esc_html__( 'Hover Active Text Color', 'parallax-frame-pro' ),
				'sub_menu_background_color'     => esc_html__( 'Sub Menu Background Color', 'parallax-frame-pro' ),
				'sub_menu_text_color'           => esc_html__( 'Sub Menu Text Color', 'parallax-frame-pro' ),
			);
			break;

		case 'secondary_menu_color':
			$options = array(
				'secondary_menu_anchor_background_color'         => esc_html__( 'Menu Anchor Background color', 'parallax-frame-pro' ),
				'secondary_menu_anchor_link_color'                    => esc_html__( 'Menu Anchor Link Color', 'parallax-frame-pro' ),
				'secondary_menu_hover_anchor_background_color' => esc_html__( 'Menu Hover Anchor Background color', 'parallax-frame-pro' ),
				'secondary_menu_hover_anchor_link_color'       => esc_html__( 'Hover Hover Anchor Link Color', 'parallax-frame-pro' ),
			);
			break;

		case 'footer_menu_color':
			$options = array(
				'footer_menu_background_color'         => esc_html__( 'Menu Background color', 'parallax-frame-pro' ),
				'footer_menu_color'                    => esc_html__( 'Menu Text Color', 'parallax-frame-pro' ),
				'footer_hover_active_background_color' => esc_html__( 'Hover Active Background Color', 'parallax-frame-pro' ),
				'footer_hover_active_text_color'       => esc_html__( 'Hover Active Text Color', 'parallax-frame-pro' ),
			);
			break;
	}

	return $options;
}
add_filter( 'parallax_frame_color_options', 'parallax_frame_get_color_options' );


/**
 * Returns an array of metabox layout options registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_metabox_layouts() {
	$options = array(
		'default' 	=> array(
			'id' 	=> 'parallax-frame-layout-option',
			'value' => 'default',
			'label' => esc_html__( 'Default', 'parallax-frame-pro' ),
		),
		'left-sidebar' 	=> array(
			'id' 	=> 'parallax-frame-layout-option',
			'value' => 'left-sidebar',
			'label' => esc_html__( 'Primary Sidebar, Content', 'parallax-frame-pro' ),
		),
		'right-sidebar' => array(
			'id' 	=> 'parallax-frame-layout-option',
			'value' => 'right-sidebar',
			'label' => esc_html__( 'Content, Primary Sidebar', 'parallax-frame-pro' ),
		),
		'no-sidebar'	=> array(
			'id' 	=> 'parallax-frame-layout-option',
			'value' => 'no-sidebar',
			'label' => esc_html__( 'No Sidebar ( Content Width )', 'parallax-frame-pro' ),
		),
		'no-sidebar-full-width' => array(
			'id' 	=> 'parallax-frame-layout-option',
			'value' => 'no-sidebar-full-width',
			'label' => esc_html__( 'No Sidebar ( Full Width )', 'parallax-frame-pro' ),
		),
	);
	return apply_filters( 'parallax_frame_layouts', $options );
}

/**
 * Returns an array of metabox header featured image options registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_metabox_header_featured_image_options() {
	$options = array(
		'default' => array(
			'id'		=> 'parallax-frame-header-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default', 'parallax-frame-pro' ),
		),
		'enable' => array(
			'id'		=> 'parallax-frame-header-image',
			'value' 	=> 'enable',
			'label' 	=> esc_html__( 'Enable', 'parallax-frame-pro' ),
		),
		'disable' => array(
			'id'		=> 'parallax-frame-header-image',
			'value' 	=> 'disable',
			'label' 	=> esc_html__( 'Disable', 'parallax-frame-pro' )
		)
	);
	return apply_filters( 'header_featured_image_options', $options );
}


/**
 * Returns an array of metabox sidebar options registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_metabox_sidebar_options() {
	$options = array(
		'main-sidebar' => array(
			'id'		=> 'parallax-frame-sidebar-options',
			'value' 	=> 'default-sidebar',
			'label' 	=> esc_html__( 'Default Sidebar', 'parallax-frame-pro' )
		),
		'optional-sidebar-one' => array(
			'id' 	=> 'parallax-frame-sidebar-options',
			'value' => 'optional-sidebar-one',
			'label' => esc_html__( 'Optional Sidebar One', 'parallax-frame-pro' )
		),
		'optional-sidebar-two' => array(
			'id' 	=> 'parallax-frame-sidebar-options',
			'value' => 'optional-sidebar-two',
			'label' => esc_html__( 'Optional Sidebar Two', 'parallax-frame-pro' )
		),
		'optional-sidebar-three' => array(
			'id' 	=> 'parallax-frame-sidebar-options',
			'value' => 'optional-sidebar-three',
			'label' => esc_html__( 'Optional Sidebar three', 'parallax-frame-pro' )
		)
	);
	return apply_filters( 'sidebar_options', $options );
}


/**
 * Returns an array of metabox featured image options registered for parallaxframe.
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_metabox_featured_image_options() {
	$options['default'] = array(
		'id'	=> 'parallax-frame-featured-image',
		'value' => 'default',
		'label' => esc_html__( 'Default', 'parallax-frame-pro' ),
	);

	$all_sizes = parallax_frame_get_additional_image_sizes();

	foreach ($all_sizes as $key => $value) {
		$options[$key] = array(
			'id'	=> 'parallax-frame-featured-image',
			'value' => $key,
			'label' => esc_html( $key ).' ('.$value['width'].'x'.$value['height'].')'
		);

	}

	$options['full'] = array(
		'id'	=> 'parallax-frame-featured-image',
		'value'	=> 'full',
		'label' => esc_html__( 'Full Image', 'parallax-frame-pro' ),
	);

	$options['disabled'] = array(
		'id' 	=> 'parallax-frame-featured-image',
		'value' => 'disabled',
		'label' => esc_html__( 'Disable Image', 'parallax-frame-pro' )
	);

	return apply_filters( 'parallax_frame_metabox_featured_image_options', $options );
}


/**
 * Returns an array of featured content background image positions
 *
 * @since parallaxframe 1.0
 */
function parallax_frame_featured_content_background_display_positions() {
	$options = array(
		'top' => array(
			'value' => 'top',
			'label' => esc_html__( 'Top', 'parallax-frame-pro' ),
		),
		'bottom' => array(
			'value' => 'bottom',
			'label' => esc_html__( 'Bottom', 'parallax-frame-pro' ),
		),
	);
	return apply_filters( 'parallax_frame_featured_content_background_display_positions', $options );
}


/**
 * Returns an array of featured content background repeat options
 *
 * @since parallaxframe 1.0
 */
function parallax_frame_featured_content_background_repeat_options() {
	 $options = array(
		'no-repeat' => array(
			'value' => 'no-repeat',
			'label' => esc_html__( 'No repeat', 'parallax-frame-pro' ),
		),
		'tile' => array(
			'value' => 'repeat',
			'label' => esc_html__( 'Tile', 'parallax-frame-pro' ),
		)
	);
	return apply_filters( 'parallax_frame_featured_content_background_repeat_options', $options );
}


/**
 * Returns an array of featured content background attachment options
 *
 * @since parallaxframe 1.0
 */
function parallax_frame_featured_content_background_attachment_options() {
	$options = array(
		'scroll' => array(
			'value' => 'scroll',
			'label' => esc_html__( 'Scroll', 'parallax-frame-pro' ),
		),
		'fixed' => array(
			'value' => 'fixed',
			'label' => esc_html__( 'Fixed', 'parallax-frame-pro' ),
		),
	);
	return apply_filters( 'parallax_frame_featured_content_background_attachment_options', $options );
}


/**
 * Returns the default options for parallaxframe dark theme.
 *
 * @since parallaxframe 1.0
 */
function parallax_frame_default_dark_color_options() {
	$default_dark_color_options = array(
		//Basic Color Options
		'background_color'                                 => '#111111',
		'text_color'                                       => '#bebebe',
		'link_color'                                       => '#e8554e',
		'link_hover_color'                                 => '#bebebe',

		//Header Color Options
		'header_textcolor'                                 => '#bebebe',
		'header_background_color'                          => '#000000',
		'site_title_hover_color'                           => '#e8554e',
		'tagline_color'                                    => '#bebebe',

		//Content Color Options
		'content_wrapper_background_color'                 => '#111111',
		'content_background_color'                         => '#111111',
		'content_title_color'                              => '#ffffff',
		'content_title_hover_color'                        => '#e8554e',
		'content_meta_color'                               => '#999999',
		'content_meta_hover_color'                         => '#e8554e',

		//Sidebar Color Options
		'sidebar_background_color'                         => '#111111',
		'sidebar_widget_title_color'                       => '#bebebe',
		'sidebar_widget_text_color'                        => '#bebebe',
		'sidebar_widget_link_color'                        => '#999999',
		'sidebar_widget_link_hover_color'                  => '#e8554e',

		//Pagination Color Options
		'pagination_background_color'                      => '#000000',
		'pagination_link_color'                            => '#ffffff',
		'pagination_text_color'                            => '#bebebe',
		'pagination_border_color'                          => '#ffffff',
		'pagination_hover_background_color'                => '#e8554e',
		'pagination_hover_link_color'                      => '#ffffff',
		'pagination_hover_border_color'                    => '#e8554e',

		//Footer Color Options
		'footer_background_color'                          => '#000000',
		'footer_text_color'                                => '#dddddd',
		'footer_link_color'                                => '#ffffff',
		'footer_link_hover_color'                          => '#dddddd',
		'footer_sidebar_area_background_color'             => '#222222',
		'footer_widget_title_color'                        => '#ffffff',
		'footer_widget_text_color'                         => '#dddddd',
		'footer_widget_link_color'                         => '#ffffff',
		'footer_widget_link_hover_color'                   => '#dddddd',

		//Promotion Headline Color Options
		'promotion_headline_background_color'              => '#111111',
		'promotion_headline_text_color'                    => '#bebebe',
		'promotion_headline_link_color'                    => '#e8554e',
		'promotion_headline_link_hover_color'              => '#bebebe',
		'promotion_headline_button_background_color'       => '#e8554e',
		'promotion_headline_button_link_color'             => '#ffffff',
		'promotion_headline_button_border_color'           => '#e8554e',
		'promotion_headline_button_hover_background_color' => '#ffffff',
		'promotion_headline_button_hover_link_color'       => '#e8554e',
		'promotion_headline_button_hover_border_color'     => '#e8554e',

		//Scrollup Color Options
		'scrollup_background_color'                        => '#000000',
		'scrollup_text_color'                              => '#ffffff',
		'scrollup_border_color'                            => '#ffffff',
		'scrollup_hover_background_color'                  => '#e8554e',
		'scrollup_hover_text_color'                        => '#ffffff',
		'scrollup_hover_border_color'                      => '#e8554e',

		//Header Highlight Content Color Options
		'header_highlight_background_color'                => '#404040',
		'header_highlight_title_color'                     => '#ffffff',
		'header_highlight_title_hover_color'               => '#e8554e',
		'header_highlight_text_color'                      => '#ffffff',
		'header_highlight_link_color'                      => '#ffffff',
		'header_highlight_link_hover_color'                => '#e8554e',
		'header_highlight_meta_color'                      => '#ffffff',
		'header_highlight_meta_hover_color'                => '#e8554e',

		//Slider Color Options
		'slider_background_color'                          => '#000000',
		'slider_text_color'                                => '#ffffff',
		'slider_link_color'                                => '#ffffff',
		'slider_link_hover_color'                          => '#ffffff',
		'slider_button_background_color'                   => 'transparent',
		'slider_button_text_color'                         => '#ffffff',
		'slider_button_border_color'                       => '#ffffff',
		'slider_button_hover_background_color'             => '#e8554e',
		'slider_button_hover_text_color'                   => '#ffffff',
		'slider_button_hover_border_color'                 => '#e8554e',

		//Hero Conent Color Options
		'hero_content_background_color'                    => 'transparent',
		'hero_content_title_color'                         => '#ffffff',
		'hero_content_text_color'                          => '#bebebe',
		'hero_content_link_color'                          => '#e8554e',
		'hero_content_link_hover_color'                    => '#bebebe',

		//Featured Content Color Options
		'featured_content_background_color'                => 'transparent',
		'featured_content_title_color'                     => '#ffffff',
		'featured_content_text_color'                      => '#ffffff',
		'featured_content_link_color'                      => '#e8554e',
		'featured_content_link_hover_color'                => '#ffffff',

		//Primary Menu Color Options
		'menu_background_color'                            => 'transparent',
		'menu_color'                                       => '#ffffff',
		'hover_active_background_color'                    => 'transparent',
		'hover_active_text_color'                          => '#e8554e',
		'sub_menu_background_color'                        => '#444444',
		'sub_menu_text_color'                              => '#ffffff',
		'sub_menu_hover_background_color'                  => '#444444',
		'sub_menu_hover_text_color'                        => '#e8554e',

		//Secondary Menu Color Options
		'secondary_menu_anchor_background_color'            => 'transparent',
		'secondary_menu_anchor_link_color'                  => '#ffffff',
		'secondary_menu_hover_anchor_background_color'      => 'transparent',
		'secondary_menu_hover_anchor_link_color'            => '#e8554e',

		//Footer Menu Color Options
		'footer_menu_background_color'                     => 'transparent',
		'footer_menu_color'                                => '#ffffff',
		'footer_hover_active_background_color'             => 'transparent',
		'footer_hover_active_text_color'                   => '#e8554e',
	);

	return apply_filters( 'parallax_frame_default_dark_color_options', $default_dark_color_options );
}


/**
 * Checks if there are options already present from Parallax Frame free version and adds it to the Parallax Frame Pro theme options
 *
 * @since Parallax Frame Pro 1.0
 * @hook after_theme_switch
 */
function parallax_frame_setup_options() {
	//Perform action only if theme_mods_theme_mods_catchbase-pro does not exist
	if ( !get_option( 'theme_mods_parallax-frame-pro' ) ) {
		//Perform action only if theme_mods_catchbase free version exists
		if ( $parallax_frame_free_options = get_option ( 'theme_mods_parallax-frame' ) ) {
			update_option('theme_mods_parallax-frame-pro', $parallax_frame_free_options );
		}
	}
}
add_action( 'after_switch_theme', 'parallax_frame_setup_options' );